<?php
/**
 * Promo Box Section options
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */

// Add Promo Box section
$wp_customize->add_section( 'mega_blog_pro_promo_box_section', array(
	'title'             => esc_html__( 'Promo Box','mega-blog-pro' ),
	'description'       => esc_html__( 'Promo Box Section options.', 'mega-blog-pro' ),
	'panel'             => 'mega_blog_pro_front_page_panel',
) );

// Promo Box content enable control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_section_enable]', array(
	'default'			=> 	$options['promo_box_section_enable'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Switch_Control( $wp_customize, 'mega_blog_pro_theme_options[promo_box_section_enable]', array(
	'label'             => esc_html__( 'Promo Box Section Enable', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_promo_box_section',
	'on_off_label' 		=> mega_blog_pro_switch_options(),
) ) );

// Promo Box us content type control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_content_type]', array(
	'default'          	=> $options['promo_box_content_type'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[promo_box_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_promo_box_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_blog_pro_is_promo_box_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-blog-pro' ),
	),
) );

// Promo Box us column type control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_column]', array(
	'default'          	=> $options['promo_box_column'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[promo_box_column]', array(
	'label'             => esc_html__( 'Column Layout', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_promo_box_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_blog_pro_is_promo_box_section_enable',
	'choices'			=> array( 
		'col-2' 		=> esc_html__( 'Two Column', 'mega-blog-pro' ),
		'col-3' 		=> esc_html__( 'Three Column', 'mega-blog-pro' ),
		'col-4' 		=> esc_html__( 'Four Column', 'mega-blog-pro' ),
	),
) );

// Promo Box posts number control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_count]', array(
	'default'          	=> $options['promo_box_count'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_number_range',
	'validate_callback' => 'mega_blog_pro_validate_promo_box_count',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[promo_box_count]', array(
	'label'             => esc_html__( 'Number of Promo Box Posts', 'mega-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_promo_box_section',
	'active_callback'   => 'mega_blog_pro_is_promo_box_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) ); 

for ( $i = 1; $i <= $options['promo_box_count']; $i++ ) :
	// promo_box pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[promo_box_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-blog-pro' ), $i ),
		'section'           => 'mega_blog_pro_promo_box_section',
		'choices'			=> mega_blog_pro_page_choices(),
		'active_callback'	=> 'mega_blog_pro_is_promo_box_section_content_page_enable',
	) ) );

	// promo_box posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_blog_pro_theme_options[promo_box_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[promo_box_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-blog-pro' ), $i ),
		'section'           => 'mega_blog_pro_promo_box_section',
		'choices'			=> mega_blog_pro_post_choices(),
		'active_callback'	=> 'mega_blog_pro_is_promo_box_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_blog_pro_theme_options[promo_box_content_category]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_blog_pro_theme_options[promo_box_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_promo_box_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_blog_pro_is_promo_box_section_content_category_enable'
) ) );
